package com.factory.wx.service.impl;

import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.wx.entity.req.AbnormalPlanReq;
import com.factory.wx.entity.res.AbnormalPlanRes;
import com.factory.wx.mapper.AbnormalStatisticsMapper;
import com.factory.wx.service.AbnormalStatisticsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author sMArT
 * @version 1.0
 * @date 2021-07-23 1:33 上午
 */
@Service("abnormalStatisticsService")
public class AbnormalStatisticsServiceImpl implements AbnormalStatisticsService {
    @Autowired
    private AbnormalStatisticsMapper abnormalStatisticsMapper;

    /**
     * 根据年月获取异常计划
     *
     * @param abnormalPlanReq
     * @return
     */
    @Override
    public List<AbnormalPlanRes> getExceptionPlansByMonth(AbnormalPlanReq abnormalPlanReq) {
        String month = getMonth(abnormalPlanReq);
        abnormalPlanReq.setMonth(month);

        List<AbnormalPlanRes> releasedAbnormalPlans = new ArrayList<>();
        //已放行
        if (abnormalPlanReq.getAbnormalType() == 2) {
            releasedAbnormalPlans.addAll(abnormalStatisticsMapper.getReleasedAbnormalPlans(abnormalPlanReq));
        }
        //已重检
        if (abnormalPlanReq.getAbnormalType() == 1) {
            releasedAbnormalPlans.addAll(abnormalStatisticsMapper.getRecheckedAbnormalPlans(abnormalPlanReq));
        }
        return releasedAbnormalPlans;
    }

    /**
     * 验证日期格式
     *
     * @param abnormalPlanReq 默认2021-06
     * @return
     */
    private String getMonth(AbnormalPlanReq abnormalPlanReq) {
        String month = "2021-06";
        try {
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM");
            Date date = simpleDateFormat.parse(abnormalPlanReq.getMonth());
            month = simpleDateFormat.format(date);
        } catch (ParseException e) {
            e.printStackTrace();
            ResponseBeanBuilder.fail("年月格式错误");
        }
        return month;
    }

}
