package com.factory.base.util.time;

import java.time.DayOfWeek;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

public class TimeUtils {
	
	static Map<Integer,String> weekInfo = new HashMap<>();
	static {
		weekInfo.put(1, "周一");
		weekInfo.put(2, "周二");
		weekInfo.put(3, "周三");
		weekInfo.put(4, "周四");
		weekInfo.put(5, "周五");
		weekInfo.put(6, "周六");
		weekInfo.put(7, "周日");
		
	}

    public static String getTimeTypeNameByLocalTime(LocalTime time) {
        String timeType = "";
        if (time == null) {
            return timeType;
        }
        if (time.getHour() <= 8) {
            timeType = "早";
        }
        if (time.getHour() >= 8 && time.getHour() <= 11) {
            timeType = "上午";
        }
        if (time.getHour() >= 14 && time.getHour() <= 18) {
            timeType = "下午";
        }
        if (time.getHour() >= 19) {
            timeType = "晚";
        }
        return timeType;
    }


    public static String getWeekInfo(int week) {
        return weekInfo.get(week);
    }
    
    public static LocalDateTime[] getStartAndEnd(LocalDateTime now,int type,int num) {
    	LocalDateTime[] se= new LocalDateTime[2];
    	if(type==1) {//日
    		se[0]=now.truncatedTo(ChronoUnit.DAYS);
    		se[1]=se[0].plusDays(num);
    	}else if(type==2) {//周
    		DayOfWeek week = now.getDayOfWeek();
    		se[0]=now.truncatedTo(ChronoUnit.DAYS).minusDays(week.getValue()-1);
    		se[1]=se[0].plusWeeks(num);
    	}else if(type==3) {//月
    		int d = now.getDayOfMonth();
    		se[0]=now.truncatedTo(ChronoUnit.DAYS).minusDays(d-1);
    		se[1]=se[0].plusMonths(num);
    	}
    	return se;
    }
    
    public static String formatLocalTime(LocalTime time) {
    	if(time==null) {
    		return "";
    	}
        return time.format(timeFormatter);
    }
    public static String getDayString(LocalDateTime now) {
    	return now.format(dayFormatter);
    }
    public static String getMonthString(LocalDateTime now) {
    	return now.format(monthFormatter);
    }
    public static String getDayTimeString(LocalDateTime now) {
    	return now.format(dayTimeFormatter);
    }
    public static LocalTime paserLocalTime(String time) {
    	if(time==null) {
    		return null;
    	}
        return LocalTime.parse(time,timeFormatter);
    }
    public static LocalDateTime paserDayString(String now) {
    	return LocalDate.parse(now,dayFormatter).atStartOfDay();
    }
    public static LocalDateTime paserMonthString(String now) {
    	return LocalDate.parse(now+"-01",dayFormatter).atStartOfDay();
    }
    public static LocalDateTime paserDayTimeString(String now) {
    	return LocalDateTime.parse(now,dayTimeFormatter);
    }
    
    public static DateTimeFormatter dayTimeFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
    public static DateTimeFormatter dayFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
    public static DateTimeFormatter timeFormatter = DateTimeFormatter.ofPattern("HH:mm:ss");
    public static DateTimeFormatter monthFormatter = DateTimeFormatter.ofPattern("yyyy-MM");
    
    public static void main(String[] args) {
    	LocalDateTime now = LocalDateTime.now();
    	System.out.println(Arrays.toString(getStartAndEnd(now,1,2)));
    	System.out.println(Arrays.toString(getStartAndEnd(now,2,2)));
    	System.out.println(Arrays.toString(getStartAndEnd(now,3,2)));
    	System.out.println(now.getDayOfMonth());
    	System.out.println(now.getDayOfWeek().getValue());
    	System.out.println(getMonthString(now));
    	System.out.println(TimeUtils.paserMonthString("2021-05"));
    }
}
